/**
 * Adds empty line when pressing enter between HTML tags.
 *
 * @category  WeBuilder Plugin
 * @package   HTML Tag Linefeed
 * @author    Peter Klein <pmk@io.dk>
 * @copyright 2016 Peter Klein
 * @license   http://www.freebsd.org/copyright/license.html  BSD License
 * @version   1.0
 */

/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 *     32   function OnKeypress(key)
 *     79   function OnInstalled()
 *
 * TOTAL FUNCTIONS: 2
 * (This index is automatically created/updated by the WeBuilder plugin "DocBlock Comments")
 *
 */

var legalCodeTypes = [dtHTML, dtXML, dtWML];

/**
 * OnKeypress event handler
 * Detects if carriage return has been pressed in the editor.
 *
 * @param  string  key: The character key pressed
 * @return string  key
 */
function OnKeypress(key) {

	if ((Document.CurrentCodeType in legalCodeTypes) && (key == Chr(13))) {
	    var uSel = Editor.Selection;
        // Line with starting tag
        var lineAbove = Editor.LinesAsDisplayed[uSel.SelStartLine - 1];

        // Is there a Tag as last item on line
        if (RegexMatchAll(Trim(lineAbove), "<([A-Z][A-Z0-9]*)\\b[^>]*>$", true, matches, NULL) == true) {
    		if (Length(matches)) {

                // Line with ending tag
                var lineBelow = Editor.LinesAsDisplayed[uSel.SelStartLine];

                // Does the starting tag has a matching ending tag on the next line?
                 if (RegexMatch(Trim(lineBelow), "^<\/" + _v(matches, [0, 1]) + ">{1}.*", true) != "") {

                    // Grab current indentation from line (Don't care if it's spaces or tabs)
                    var	ind = RegexMatch(lineBelow, "^\\s*", false);

                    Editor.BeginEditing;

                    // Insert extra linefeed
                    Editor.SelText = chr(13) + ind;
                    Editor.Selection = uSel;

                    // Move selection to end of line
                    uSel.SelStartCol = Length(ind) + Script.Settings.BlockIndent;
                    uSel.SelEndCol = uSel.SelStartCol;
                    Editor.Selection = uSel;

                    Editor.EndEditing;

                }
            }
            key = "";
        }
	}

    return key;
}

/**
 * Show info when plugin is installed
 *
 * @return void
 */
function OnInstalled() {
  Alert("HTML Tag Linefeed 1.0 by Peter Klein installed sucessfully!");
}

Script.ConnectSignal("installed", "OnInstalled");
Script.ConnectSignal("keypress", "OnKeypress");
